#[repr(i32)]pub enum OpenMode {
Undefined = 16,
Read = 17,
ReadAsync = 18,
Write = 19,
Append = 20,
ReadWrite = 21,
ReadWriteAppend = 22,
}Expand description
How a file should be opened, passed to MtFile::open.
Variants
Undefined = 16
No/invalid mode.
Read = 17
Open an existing file for reading.
ReadAsync = 18
Open an existing file for asynchronous reading.
Write = 19
Create or truncate a file for writing.
Append = 20
Open a file for writing, appending to the end.
ReadWrite = 21
Open a file for both reading and writing.
ReadWriteAppend = 22
Open a file for reading and writing, appending to the end.