pub struct Event { /* private fields */ }Expand description
A kernel event object that threads can signal and wait on.
Implementations
Sourceimpl Event
impl Event
Sourcepub fn new(signaled: bool, clear_mode: EventClearMode) -> Self
pub fn new(signaled: bool, clear_mode: EventClearMode) -> Self
Creates a new event. If signaled is true the event starts in the signaled state.
Sourcepub fn try_wait(&self) -> bool
pub fn try_wait(&self) -> bool
Returns true if the event is currently signaled without blocking.
Sourcepub fn wait_timeout(&self, timeout: Duration) -> bool
pub fn wait_timeout(&self, timeout: Duration) -> bool
Blocks until the event is signaled or timeout elapses. Returns true if signaled.