pub struct LightEvent { /* private fields */ }Expand description
A lightweight event object with the same API as Event but suitable for const initialization.
Implementations
Sourceimpl LightEvent
impl LightEvent
Sourcepub const fn new(signaled: bool, clear_mode: EventClearMode) -> Self
pub const fn new(signaled: bool, clear_mode: EventClearMode) -> Self
Creates a new light event. If signaled is true the event starts in the signaled state.
Sourcepub fn try_wait(&self) -> bool
pub fn try_wait(&self) -> bool
Returns true if the event is currently signaled without blocking.
Sourcepub fn wait_timeout(&self, timeout: Duration) -> bool
pub fn wait_timeout(&self, timeout: Duration) -> bool
Blocks until the event is signaled or timeout elapses. Returns true if signaled.