Module this_thread

Module this_thread 

Functions for querying and controlling the calling thread.

Functions

core
Returns the core number the calling thread is currently running on.
processor
Returns the logical processor number the calling thread is currently running on.
sleep_for
Suspends the calling thread for at least duration.
yield_now
Yields the calling thread’s remaining timeslice to the scheduler.