Module thread

Module thread 

Structs

Builder
A builder for configuring and spawning threads.
Thread
An OS thread handle.

Constants

STACK_ALIGNMENT

Functions

spawn
Spawns a new thread that runs f, allocating a dynamic stack of stack_size bytes.
spawn_halted
Like spawn, but the thread is created in a halted state and must be started with Thread::start.
spawn_halted_with
Like spawn_with, but the thread is created in a halted state and must be started with Thread::start.
spawn_with
Spawns a new thread that runs f, using the provided static stack buffer.