pub struct Upload { /* private fields */ }Expand description
A file upload from a multipart form.
This type is used for receiving file uploads in mutations. It cannot be stored directly in the database (attempting to convert to SQL type will panic).
Examples
use forge_core::types::Upload;
use bytes::Bytes;
let upload = Upload::new("document.pdf", "application/pdf", Bytes::from("content"));
println!("Received: {} ({} bytes)", upload.name(), upload.len());Implementations
Sourceimpl Upload
impl Upload
Sourcepub fn new(
name: impl Into<String>,
content_type: impl Into<String>,
bytes: Bytes,
) -> Upload
pub fn new( name: impl Into<String>, content_type: impl Into<String>, bytes: Bytes, ) -> Upload
Create a new upload from parts.
Sourcepub fn from_bytes(name: impl Into<String>, bytes: Bytes) -> Upload
pub fn from_bytes(name: impl Into<String>, bytes: Bytes) -> Upload
Create an upload from raw bytes with a default content type.
Sourcepub fn content_type(&self) -> &str
pub fn content_type(&self) -> &str
Get the content type (MIME type).
Sourcepub fn into_bytes(self) -> Bytes
pub fn into_bytes(self) -> Bytes
Consume the upload and return the bytes.