Re-exports
pub extern crate forge_macros as macros;pub extern crate forge_rt as rt;pub extern crate forge_sys as sys;
Modules
Macros
- install_
hook - Installs a hook generated by
#[forge::hook]. - update_
hook_ ctx - Updates the context for an already-installed hook.
Structs
Constants
Attribute Macros
- entry
- Marks a function as the plugins entry point.
- hook
- Defines a function hook at a fixed offset from a base address.
- pure_
virtual - Marks a method as a virtual function at a given index in the vtable.
Methods marked with this must be part of a type that implements
HasVtable, and must take&selfor&mut selfas the first parameter. The method body is replaced with a call to the function pointer at the specified index in the vtable