Crate forge

Crate forge 

Re-exports

pub extern crate forge_macros as macros;
pub extern crate forge_rt as rt;
pub extern crate forge_sys as sys;

Modules

hook
log
mem
mt
patch
singleton
socket

Macros

install_hook
Installs a hook generated by #[forge::hook].
update_hook_ctx
Updates the context for an already-installed hook.

Structs

ForgeVersion
PluginInitParams

Constants

REQUIRED_VERSION

Attribute Macros

entry
Marks a function as the plugins entry point.
hook
Defines a function hook at a fixed offset from a base address.
pure_virtual
Marks a method as a virtual function at a given index in the vtable. Methods marked with this must be part of a type that implements HasVtable, and must take &self or &mut self as the first parameter. The method body is replaced with a call to the function pointer at the specified index in the vtable

Derive Macros

CacheDti
HasVtable
Object