Module this_thread
forge
1.4.1
Module this_
thread
Module Items
Functions
In forge::
os
forge
::
os
Module
this_
thread
Functions for querying and controlling the calling thread.
Functions

core
Returns the core number the calling thread is currently running on.
processor
Returns the logical processor number the calling thread is currently running on.
sleep_
for
Suspends the calling thread for at least
duration
.
yield_
now
Yields the calling thread’s remaining timeslice to the scheduler.