pub fn spawn_halted<F: FnOnce() + Send + 'static>( f: F, stack_size: usize, priority: i32, ) -> Thread
Like spawn, but the thread is created in a halted state and must be started with Thread::start.
spawn
Thread::start