Module prelude

Module prelude 

Prelude module for common imports.

Re-exports

pub use crate::Forge;
pub use crate::ForgeBuilder;
pub use serde_json;
pub use axum;

Structs

AuthContext
Authentication context available to all functions.
CronContext
Context available to cron handlers.
DaemonContext
Context available to daemon handlers.
DateTime
ISO 8601 combined date and time with time zone.
Delta
Delta format for subscription updates.
FieldDef
Definition of a model field.
ForgeConfig
Root configuration for FORGE.
JobContext
Context available to job handlers.
McpToolContext
Context for MCP tool execution.
McpToolResult
Tool execution payload returned by MCP tool handlers.
MutationContext
Context for mutation functions (transactional database access).
QueryContext
Context for query functions (read-only database access).
SchemaRegistry
Global registry of all schema definitions. This is populated at compile time by the proc macros. Uses BTreeMap for deterministic iteration order.
TableDef
Complete table definition.
TokenPair
An access token + refresh token pair.
Upload
A file upload from a multipart form.
Utc
The UTC time zone. This is the most efficient time zone when you don’t need the local time. It is also used as an offset (which is also a dummy type).
Uuid
A Universally Unique Identifier (UUID).
WebhookContext
Context available to webhook handlers.
WebhookSignature
Helper for constructing signature configurations.
WorkflowContext
Context available to workflow handlers.

Enums

DbConn
Abstraction over pool and transaction connections.
ForgeError
Core error type for Forge operations.
JobPriority
Job priority levels.
NodeRole
Node role in the cluster.
WebhookResult
Result returned by webhook handlers.

Traits

Deserialize
A data structure that can be deserialized from any data format supported by Serde.
EnvAccess
Extension methods for environment variable access on contexts.
ForgeCron
Trait for cron job handlers.
ForgeDaemon
Trait for FORGE daemon handlers.
ForgeJob
Trait for FORGE job handlers.
ForgeMcpTool
Trait implemented by all FORGE MCP tools.
ForgeMutation
A mutation function (transactional write).
ForgeQuery
A query function (read-only, cacheable, subscribable).
ForgeWebhook
Trait for FORGE webhook handlers.
ForgeWorkflow
Trait for workflow handlers.
JsonSchema
A type which can be described as a JSON Schema document.
ModelMeta
Trait implemented by all FORGE models. Generated by the #[forge::model] macro.
Serialize
A data structure that can be serialized into any data format supported by Serde.

Type Aliases

Result
Result type alias using ForgeError.
Timestamp
Timestamp type alias for convenience.

Derive Macros

Deserialize
JsonSchema
Serialize