Prelude module for common imports.
Re-exports
pub use crate::Forge;pub use crate::ForgeBuilder;pub use serde_json;pub use axum;
Structs
- Auth
Context - Authentication context available to all functions.
- Cron
Context - Context available to cron handlers.
- Daemon
Context - Context available to daemon handlers.
- Date
Time - ISO 8601 combined date and time with time zone.
- Delta
- Delta format for subscription updates.
- Field
Def - Definition of a model field.
- Forge
Config - Root configuration for FORGE.
- JobContext
- Context available to job handlers.
- McpTool
Context - Context for MCP tool execution.
- McpTool
Result - Tool execution payload returned by MCP tool handlers.
- Mutation
Context - Context for mutation functions (transactional database access).
- Query
Context - Context for query functions (read-only database access).
- Schema
Registry - Global registry of all schema definitions. This is populated at compile time by the proc macros. Uses BTreeMap for deterministic iteration order.
- Table
Def - Complete table definition.
- Token
Pair - An access token + refresh token pair.
- Upload
- A file upload from a multipart form.
- Utc
- The UTC time zone. This is the most efficient time zone when you don’t need the local time. It is also used as an offset (which is also a dummy type).
- Uuid
- A Universally Unique Identifier (UUID).
- Webhook
Context - Context available to webhook handlers.
- Webhook
Signature - Helper for constructing signature configurations.
- Workflow
Context - Context available to workflow handlers.
Enums
- DbConn
- Abstraction over pool and transaction connections.
- Forge
Error - Core error type for Forge operations.
- JobPriority
- Job priority levels.
- Node
Role - Node role in the cluster.
- Webhook
Result - Result returned by webhook handlers.
Traits
- Deserialize
- A data structure that can be deserialized from any data format supported by Serde.
- EnvAccess
- Extension methods for environment variable access on contexts.
- Forge
Cron - Trait for cron job handlers.
- Forge
Daemon - Trait for FORGE daemon handlers.
- Forge
Job - Trait for FORGE job handlers.
- Forge
McpTool - Trait implemented by all FORGE MCP tools.
- Forge
Mutation - A mutation function (transactional write).
- Forge
Query - A query function (read-only, cacheable, subscribable).
- Forge
Webhook - Trait for FORGE webhook handlers.
- Forge
Workflow - Trait for workflow handlers.
- Json
Schema - A type which can be described as a JSON Schema document.
- Model
Meta - Trait implemented by all FORGE models. Generated by the #[forge::model] macro.
- Serialize
- A data structure that can be serialized into any data format supported by Serde.